@@ -11,16 +11,12 @@ describe 'glance::api' do
     {
       :bind_host                => '<SERVICE DEFAULT>',
       :bind_port                => '9292',
-      :registry_host            => '0.0.0.0',
-      :registry_port            => '<SERVICE DEFAULT>',
-      :registry_client_protocol => '<SERVICE DEFAULT>',
       :auth_strategy            => 'keystone',
       :enabled                  => true,
       :manage_service           => true,
       :backlog                  => '<SERVICE DEFAULT>',
       :workers                  => '7',
       :show_image_direct_url    => '<SERVICE DEFAULT>',
-      :show_multiple_locations  => '<SERVICE DEFAULT>',
       :filesystem_store_metadata_file => '<SERVICE DEFAULT>',
       :filesystem_store_file_perm => '<SERVICE DEFAULT>',
       :location_strategy        => '<SERVICE DEFAULT>',
